## $Id: interfaces.py 17635 2023-11-06 20:09:17Z henrik $
##
## Copyright (C) 2011 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##

import zope.i18nmessageid
from zope import schema
from zc.sourcefactory.basic import BasicSourceFactory
from waeup.kofa.interfaces import (SimpleKofaVocabulary,
    ISessionConfiguration, academic_sessions_vocab)

_ = MessageFactory = zope.i18nmessageid.MessageFactory('kofacustom.edopoly')

class ICustomSessionConfiguration(ISessionConfiguration):
    """A session configuration object.
    """

    # Base fees, do not remove.

    clearance_fee = schema.Float(
        title = _(u'Acceptance Fee'),
        default = 0.0,
        required = False,
        )

    booking_fee = schema.Float(
        title = _(u'Bed Booking Fee'),
        default = 0.0,
        required = False,
        )

    maint_fee = schema.Float(
        title = _(u'Rent (fallback)'),
        default = 0.0,
        required = False,
        )

    late_registration_fee = schema.Float(
        title = _(u'Late Course Reg. Fee'),
        default = 0.0,
        required = False,
        )

    transcript_fee = schema.Float(
        title = _(u'Transcript Fee'),
        default = 0.0,
        required = False,
        )

    transfer_fee = schema.Float(
        title = _(u'Transfer Fee'),
        default = 0.0,
        required = False,
        )

    # Additional fees in custom package add here

    admchecking_fee = schema.Float(
        title = _(u'Admission Checking Fee'),
        default = 0.0,
        required = False,
        )

    logbook_combo_fee = schema.Float(
        title = _(u'Logbook Combo Fee'),
        default = 0.0,
        required = False,
        )

    ict_entre_fee = schema.Float(
        title = _(u'ICT & Entrepreneur Fee'),
        default = 0.0,
        required = False,
        )

    siwess_combo_fee = schema.Float(
        title = _(u'SIWESS Combo Fee'),
        default = 0.0,
        required = False,
        )

    certificate_fee = schema.Float(
        title = _(u'Certificate Fee'),
        default = 0.0,
        required = False,
        )

    certificate_confirm_fee = schema.Float(
        title = _(u'Certificate Confirmation Fee'),
        default = 0.0,
        required = False,
        )

    final_clearance_fee = schema.Float(
        title = _(u'Final Clearance Fee'),
        default = 0.0,
        required = False,
        )

    union_fee = schema.Float(
        title = _(u'Student Union Dues'),
        default = 0.0,
        required = False,
        )

    medical_fee = schema.Float(
        title = _(u'Medical Laboratory Test Fee'),
        default = 0.0,
        required = False,
        )

    conv_nd_fee = schema.Float(
        title = _(u'Convocation Fee ND'),
        default = 0.0,
        required = False,
        )

    conv_hnd_fee = schema.Float(
        title = _(u'Convocation Fee HND'),
        default = 0.0,
        required = False,
        )

    nhis_fee = schema.Float(
        title = _(u'TISHIP Fee'),
        default = 0.0,
        required = False,
        )

    coc_fee = schema.Float(
        title = _(u'Change of Course Fee'),
        default = 0.0,
        required = False,
        )

    damages_fee = schema.Float(
        title = _(u'Damages Fee'),
        default = 0.0,
        required = False,
        )

    project_bind_fee = schema.Float(
        title = _(u'Project Binding Fee'),
        default = 0.0,
        required = False,
        )

    maintenance_fee = schema.Float(
        title = _(u'Maintenance and Utility Fees'),
        default = 0.0,
        required = False,
        )

    cyber_fee = schema.Float(
        title = _(u'Cyber Security Fee'),
        default = 0.0,
        required = False,
        )

    ispon_fee = schema.Float(
        title = _(u'ISPON Safety Fee'),
        default = 0.0,
        required = False,
        )

    indigene_fee = schema.Float(
        title = _(u'Non-State Indigene Fee'),
        default = 0.0,
        required = False,
        )
    develop_fee = schema.Float(
        title = _(u'Development Fee'),
        default = 0.0,
        required = False,
        )        

    sport_fee = schema.Float(
        title = _(u'Sport Development Fee'),
        default = 0.0,
        required = False,
        )
        
    gown_fee = schema.Float(
        title = _(u'Matriculation Gown Fee'),
        default = 0.0,
        required = False,
        )

    global_practics_fee = schema.Float(
        title = _(u'Global Practics Fee'),
        default = 0.0,
        required = False,
        )

    def getSessionString():
        """Returns the session string from the vocabulary.
        """


class ICustomSessionConfigurationAdd(ICustomSessionConfiguration):
    """A session configuration object in add mode.
    """

    academic_session = schema.Choice(
        title = _(u'Academic Session'),
        source = academic_sessions_vocab,
        default = None,
        required = True,
        readonly = False,
        )

ICustomSessionConfigurationAdd[
    'academic_session'].order =  ICustomSessionConfiguration[
    'academic_session'].order